/* mohawk - small HTTP server
**
** Copyright © 2010 by Baptiste Daroussin <bapt@FreeBSD.org>,
** Copyright © 2010 by Freddy Dissaux <freddy.dsx@free.fr>,
** All rights reserved.
**
** Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions
** are met:
** 1. Redistributions of source code must retain the above copyright
**    notice, this list of conditions and the following disclaimer.
** 2. Redistributions in binary form must reproduce the above copyright
**    notice, this list of conditions and the following disclaimer in the
**    documentation and/or other materials provided with the distribution.
**
** THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
** ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
** IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
** ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
** FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
** DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
** OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
** HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
** LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
** OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
** SUCH DAMAGE.
*/
%option nounput

%{
#include <err.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <err.h>
#include <sys/limits.h>
#include "parse.h"

char *
words(char *s)
{
	char *p;
	p = strrchr(s, '"');
	*p = '\0';
	p = s;
	p++;
	return p;
}

int
parse_number(const char *s)
{
	const char *errstr;
	int res = strtonum(s, 0, INT_MAX, &errstr);
	if (errstr)
		errx(1, "parse_number '%s': %s\n", s, errstr);
	return res;
}

%}

%%
set              return SET;
reset            return RESET;
debug            return DEBUG;
cgi_pattern      return CGI_PATTERN;
mime             return MIME;
chroot           return CHROOT;
index_name       return INDEX_NAME;
rootdir          return ROOTDIR; 
dirlist_css_url  return DIRLIST_CSS_URL;
charset          return CHARSET;
user             return USER;
pidfile          return PIDFILE;
status_url       return STATUS_URL;
listen           return LISTEN;
port             return PORT;
cgi_map          return CGI_MAP;
vhost            return VHOST;
cgi_env          return CGI_ENV;
default          return DEFAULT;
no_log           return NO_LOG;
restrict_from    return RESTRICT_FROM;
maxage           return MAXAGE;
x_forwarded_for  return X_FORWARDED_FOR;
\{               return OBRACE;
\}               return EBRACE;
on|off              yylval.number =! strcmp(yytext, "on"); return STATE;
\"[^\"]*\"          yylval.string = strdup(words(yytext)); return WORDS;
[0-9]+              yylval.number = parse_number(yytext); return NUMBER;
[a-zA-Z0-9\/.*_-]+  yylval.string = strdup(yytext); return WORD;
[ \t]+                  /* ignore whitespace */;
\n                      /* ignore eol */;
#.*                     /* ignore comment */;
%%

/* vim: set sw=4 sts=4 ts=4 : */
